@@ -45,7 +45,7 @@ class DfConverter:
         for c in columns:
             # get data
             data = dataframe[c].to_list()
-            dataframe = pd.concat([dataframe, pd.json_normalize(data)], axis=1)
+            dataframe = pd.concat([dataframe, pd.json_normalize(data).add_prefix(c + ".")], axis=1)
 
         # DROP
         if drop:
